%global _gitlablibdir %{_exec_prefix}/lib
%global ld_library_path LD_LIBRARY_PATH=/opt/rh/nodejs010/root/lib64/:/opt/rh/v8314/root/usr/lib64/

Name:    gitlab
Version: 8.12.1
Release: 1
Summary: Software Development Platform
Group:   Development/Tools
License: Expat
URL:     https://softwarepublico.gov.br/gitlab/softwarepublico/gitlab
Source0: %{name}-%{version}.tar.gz
BuildRequires: ruby >= 2.3.1
BuildRequires: gitlab-deps
BuildRequires: git >= 2.9.3
BuildRequires: nodejs
BuildRequires: libuv
BuildRequires: gitlab-shell
BuildRequires: gitlab-workhorse

Requires: gitlab-shell
Requires: ruby >= 2.3.1 
Requires: git >= 2.9.3 
Requires: libuv
Requires: gitlab-workhorse
Requires: gitlab-deps
Requires: nodejs010

%description
GitLab

%prep
%setup -q

%build
cat > config/gitlab.yml <<EOF
production: &base
  gitlab:
    relative_url_root: /gitlab
    host: localhost
    port: 80 # Set to 443 if using HTTPS
    https: false # Set to true if using HTTPS
    email_from: example@example.com
    default_projects_limit: 10
    default_projects_features:
      issues: true
      merge_requests: true
      wiki: true
      snippets: false
      visibility_level: "private"  # can be "private" | "internal" | "public"
  gravatar:
    enabled: true
    plain_url: "http://cdn.libravatar.org/avatar/%{hash}?s=%{size}&d=identicon"
    ssl_url: "https://seccdn.libravatar.org/avatar/%{hash}?s=%{size}&d=identicon"
  omniauth:
    # Allow login via Twitter, Google, etc. using OmniAuth providers
    enabled: false
    allow_single_sign_on: ["saml"]
    block_auto_created_users: true
    providers:
      # - { name: 'google_oauth2', app_id: 'YOUR APP ID',
      #     app_secret: 'YOUR APP SECRET',
      #     args: { access_type: 'offline', approval_prompt: '' } }
  backup:
    path: %{_sharedstatedir}/gitlab/backups
  gitlab_shell:
    path: %{_gitlablibdir}/gitlab-shell
    repos_path: %{_sharedstatedir}/gitlab-shell/repositories/
    hooks_path: %{_gitlablibdir}/gitlab-shell/hooks/
    # Git over HTTP
    upload_pack: true
    receive_pack: true
  git:
    bin_path: /usr/bin/git
    max_size: 20971520 # 20.megabytes
    timeout: 10
  extra:
EOF

################################################
%install
mkdir -p                          %{buildroot}%{_sysconfdir}/gitlab
mv config/gitlab.yml              %{buildroot}/etc/gitlab/gitlab.yml
cp config/unicorn.rb.example      %{buildroot}/etc/gitlab/unicorn.rb
cp config/database.yml.postgresql %{buildroot}/etc/gitlab/database.yml


cat > config/initializers/no_asset_compile.rb <<EOF
Gitlab::Application.configure do
  # assets already compiled
  config.assets.compile = false
end
EOF

sed -i 's/\/home\/\git/\/usr\/lib/' %{buildroot}/etc/gitlab/unicorn.rb


mkdir -p %{buildroot}%{_gitlablibdir}/gitlab
cp -r app bin config config.ru db doc fixtures GITLAB_SHELL_VERSION lib Procfile public Rakefile vendor VERSION %{buildroot}/%{_gitlablibdir}/gitlab/

for configfile in unicorn.rb database.yml gitlab.yml; do
    ln -s %{_sysconfdir}/gitlab/$configfile %{buildroot}/%{_gitlablibdir}/gitlab/config/$configfile
done

rm -rf %{buildroot}/%{_gitlablibdir}/gitlab/public/uploads
mv %{buildroot}/%{_gitlablibdir}/gitlab/config/initializers/rack_attack.rb.example %{buildroot}/%{_gitlablibdir}/gitlab/config/initializers/rack_attack.rb

mkdir -p %{buildroot}%{_sysconfdir}/default/
cp %{buildroot}/%{_gitlablibdir}/gitlab/lib/support/init.d/gitlab.default.example %{buildroot}%{_sysconfdir}/default/gitlab

sed -i 's|gitlab_workhorse_dir=$(cd $app_root/../gitlab-workhorse && pwd)|gitlab_workhorse_dir="/usr/local/bin/"|' %{buildroot}/%{_sysconfdir}/default/gitlab
sed -i 's|app_root="/home/$app_user/gitlab"|app_root="/usr/lib/gitlab"|' %{buildroot}/%{_sysconfdir}/default/gitlab
sed -i 's|127.0.0.1:8080|127.0.0.1:8080/gitlab|' %{buildroot}/%{_sysconfdir}/default/gitlab

install -d %{buildroot}/var/log/gitlab/
install -d %{buildroot}/var/log/gitlab/repositories
install -d %{buildroot}/%{_sharedstatedir}/gitlab/uploads
install -d -m ug+rwX,o-rwx %{buildroot}/%{_sharedstatedir}/gitlab-shell/
install -d %{buildroot}/%{_sharedstatedir}/gitlab-shell/repositories
install -d  %{buildroot}/%{_sharedstatedir}/gitlab-assets/
cp %{buildroot}/%{_gitlablibdir}/gitlab/config/secrets.yml{.example,}
install -d %{buildroot}/%{_sysconfdir}/gitlab-shell/

ln -s /var/log/gitlab %{buildroot}/%{_gitlablibdir}/gitlab/log
ln -s %{_sharedstatedir}/gitlab/uploads %{buildroot}/%{_gitlablibdir}/gitlab/public/uploads
ln -s %{_sharedstatedir}/gitlab-assets  %{buildroot}/%{_gitlablibdir}/gitlab/public/assets

%post

if [ -x /usr/bin/postgres ]; then
  service postgresql initdb || true
  service postgresql start
  sudo -u postgres createuser --createdb git || true
fi

touch %{_sharedstatedir}/gitlab/.gitconfig
ln -sf %{_sharedstatedir}/gitlab/.gitconfig %{_gitlablibdir}/gitlab/.gitconfig

if [ /usr/bin/redis-server ]; then
  service redis start
fi

chown -R git:redis /var/run/redis/redis.sock
usermod -aG redis git

chown -R git:git /usr/lib/gitlab/
chown -R git:git /usr/lib/gitlab-shell/

sudo -u git -H "/usr/bin/git" config --global user.name  "GitLab"
sudo -u git -H "/usr/bin/git" config --global user.email "example@example.com"
sudo -u git -H "/usr/bin/git" config --global core.autocrlf "input"

cd %{_gitlablibdir}/gitlab/

sudo -u git env bundle exec rake assets:precompile RAILS_ENV=production

cp %{_gitlablibdir}/gitlab/lib/support/init.d/gitlab %{_sysconfdir}/init.d/gitlab
cp %{_gitlablibdir}/gitlab/lib/support/logrotate/gitlab %{_sysconfdir}/logrotate.d/gitlab

##################### Relative Url ###############
sed -i 's|# config.relative_url_root|config.relative_url_root|' %{_gitlablibdir}/gitlab/config/application.rb
sed -i 's|# relative_url_root|relative_url_root|' %{_gitlablibdir}/gitlab/config/gitlab.yml
sed -i "s|# ENV\['RAILS_RELATIVE_URL_ROOT']|ENV\['RAILS_RELATIVE_URL_ROOT']|" %{_gitlablibdir}/gitlab/config/unicorn.rb
sed -i 's|gitlab_url: "http://localhost:8080/"|gitlab_url: "http://localhost:8080/gitlab"|' %{_gitlablibdir}/gitlab-shell/config.yml
################################################

%preun
systemctl stop gitlab
systemctl disable gitlab

%files
%{_gitlablibdir}/gitlab
%config(noreplace) %{_sysconfdir}/gitlab/database.yml
%config(noreplace) %{_sysconfdir}/gitlab/gitlab.yml
%config(noreplace) %{_sysconfdir}/gitlab/unicorn.rb
%config            %{_sysconfdir}/default/gitlab
%attr(0770, git, git) %{_sysconfdir}/gitlab/*
%attr(0770, git, git) /var/log/gitlab/
%attr(0770, git, git) /var/lib/gitlab/
%attr(0770, git, git) /var/lib/gitlab-assets/
%attr(0770, git, git) /var/lib/gitlab-shell/
%attr(0770, git, git) /usr/lib/gitlab/db/schema.rb
